Installation
============
This software can be installed in multiple ways. The ways that are recommended are as follows.

Obtaining the Source
^^^^^^^^^^^^^^^^^^^^
This is a library targeted specifcally to developers so you will most likely want to get your hands on the source. It can be obtained as follows.::

    $ git clone git://github.com/myusuf3/delorean.git

Installing from PyPi
^^^^^^^^^^^^^^^^^^^^

I would personally recommend using `pip <http://www.pip-installer.org/en/latest/>`_ but any of the following ways should work.

To install simply run::

    $ pip install delorean

or if you must `easy_install <http://packages.python.org/distribute/easy_install.html>`_ ::

    $ easy_install delorean

Installing from Source
^^^^^^^^^^^^^^^^^^^^^^

If you have a copy of the source simply running the following from the root directory should have the same effect.::

    $ python setup.py install
